/**
 * almond 0.2.7 Copyright (c) 2011-2012, The Dojo Foundation All Rights Reserved.
 * Available via the MIT or new BSD license.
 * see: http://github.com/jrburke/almond for details
 */
//Going sloppy to avoid 'use strict' string cost, but strict practices should
//be followed.
/*jslint sloppy: true */
/*global setTimeout: false */

var requirejs, require, define;
(function (undef) {
    var main, req, makeMap, handlers,
        defined = {},
        waiting = {},
        config = {},
        defining = {},
        hasOwn = Object.prototype.hasOwnProperty,
        aps = [].slice;

    function hasProp(obj, prop) {
        return hasOwn.call(obj, prop);
    }

    /**
     * Given a relative module name, like ./something, normalize it to
     * a real name that can be mapped to a path.
     * @param {String} name the relative name
     * @param {String} baseName a real name that the name arg is relative
     * to.
     * @returns {String} normalized name
     */
    function normalize(name, baseName) {
        var nameParts, nameSegment, mapValue, foundMap,
            foundI, foundStarMap, starI, i, j, part,
            baseParts = baseName && baseName.split("/"),
            map = config.map,
            starMap = (map && map['*']) || {};

        //Adjust any relative paths.
        if (name && name.charAt(0) === ".") {
            //If have a base name, try to normalize against it,
            //otherwise, assume it is a top-level require that will
            //be relative to baseUrl in the end.
            if (baseName) {
                //Convert baseName to array, and lop off the last part,
                //so that . matches that "directory" and not name of the baseName's
                //module. For instance, baseName of "one/two/three", maps to
                //"one/two/three.js", but we want the directory, "one/two" for
                //this normalization.
                baseParts = baseParts.slice(0, baseParts.length - 1);

                name = baseParts.concat(name.split("/"));

                //start trimDots
                for (i = 0; i < name.length; i += 1) {
                    part = name[i];
                    if (part === ".") {
                        name.splice(i, 1);
                        i -= 1;
                    } else if (part === "..") {
                        if (i === 1 && (name[2] === '..' || name[0] === '..')) {
                            //End of the line. Keep at least one non-dot
                            //path segment at the front so it can be mapped
                            //correctly to disk. Otherwise, there is likely
                            //no path mapping for a path starting with '..'.
                            //This can still fail, but catches the most reasonable
                            //uses of ..
                            break;
                        } else if (i > 0) {
                            name.splice(i - 1, 2);
                            i -= 2;
                        }
                    }
                }
                //end trimDots

                name = name.join("/");
            } else if (name.indexOf('./') === 0) {
                // No baseName, so this is ID is resolved relative
                // to baseUrl, pull off the leading dot.
                name = name.substring(2);
            }
        }

        //Apply map config if available.
        if ((baseParts || starMap) && map) {
            nameParts = name.split('/');

            for (i = nameParts.length; i > 0; i -= 1) {
                nameSegment = nameParts.slice(0, i).join("/");

                if (baseParts) {
                    //Find the longest baseName segment match in the config.
                    //So, do joins on the biggest to smallest lengths of baseParts.
                    for (j = baseParts.length; j > 0; j -= 1) {
                        mapValue = map[baseParts.slice(0, j).join('/')];

                        //baseName segment has  config, find if it has one for
                        //this name.
                        if (mapValue) {
                            mapValue = mapValue[nameSegment];
                            if (mapValue) {
                                //Match, update name to the new value.
                                foundMap = mapValue;
                                foundI = i;
                                break;
                            }
                        }
                    }
                }

                if (foundMap) {
                    break;
                }

                //Check for a star map match, but just hold on to it,
                //if there is a shorter segment match later in a matching
                //config, then favor over this star map.
                if (!foundStarMap && starMap && starMap[nameSegment]) {
                    foundStarMap = starMap[nameSegment];
                    starI = i;
                }
            }

            if (!foundMap && foundStarMap) {
                foundMap = foundStarMap;
                foundI = starI;
            }

            if (foundMap) {
                nameParts.splice(0, foundI, foundMap);
                name = nameParts.join('/');
            }
        }

        return name;
    }

    function makeRequire(relName, forceSync) {
        return function () {
            //A version of a require function that passes a moduleName
            //value for items that may need to
            //look up paths relative to the moduleName
            return req.apply(undef, aps.call(arguments, 0).concat([relName, forceSync]));
        };
    }

    function makeNormalize(relName) {
        return function (name) {
            return normalize(name, relName);
        };
    }

    function makeLoad(depName) {
        return function (value) {
            defined[depName] = value;
        };
    }

    function callDep(name) {
        if (hasProp(waiting, name)) {
            var args = waiting[name];
            delete waiting[name];
            defining[name] = true;
            main.apply(undef, args);
        }

        if (!hasProp(defined, name) && !hasProp(defining, name)) {
            throw new Error('No ' + name);
        }
        return defined[name];
    }

    //Turns a plugin!resource to [plugin, resource]
    //with the plugin being undefined if the name
    //did not have a plugin prefix.
    function splitPrefix(name) {
        var prefix,
            index = name ? name.indexOf('!') : -1;
        if (index > -1) {
            prefix = name.substring(0, index);
            name = name.substring(index + 1, name.length);
        }
        return [prefix, name];
    }

    /**
     * Makes a name map, normalizing the name, and using a plugin
     * for normalization if necessary. Grabs a ref to plugin
     * too, as an optimization.
     */
    makeMap = function (name, relName) {
        var plugin,
            parts = splitPrefix(name),
            prefix = parts[0];

        name = parts[1];

        if (prefix) {
            prefix = normalize(prefix, relName);
            plugin = callDep(prefix);
        }

        //Normalize according
        if (prefix) {
            if (plugin && plugin.normalize) {
                name = plugin.normalize(name, makeNormalize(relName));
            } else {
                name = normalize(name, relName);
            }
        } else {
            name = normalize(name, relName);
            parts = splitPrefix(name);
            prefix = parts[0];
            name = parts[1];
            if (prefix) {
                plugin = callDep(prefix);
            }
        }

        //Using ridiculous property names for space reasons
        return {
            f: prefix ? prefix + '!' + name : name, //fullName
            n: name,
            pr: prefix,
            p: plugin
        };
    };

    function makeConfig(name) {
        return function () {
            return (config && config.config && config.config[name]) || {};
        };
    }

    handlers = {
        require: function (name) {
            return makeRequire(name);
        },
        exports: function (name) {
            var e = defined[name];
            if (typeof e !== 'undefined') {
                return e;
            } else {
                return (defined[name] = {});
            }
        },
        module: function (name) {
            return {
                id: name,
                uri: '',
                exports: defined[name],
                config: makeConfig(name)
            };
        }
    };

    main = function (name, deps, callback, relName) {
        var cjsModule, depName, ret, map, i,
            args = [],
            callbackType = typeof callback,
            usingExports;

        //Use name if no relName
        relName = relName || name;

        //Call the callback to define the module, if necessary.
        if (callbackType === 'undefined' || callbackType === 'function') {
            //Pull out the defined dependencies and pass the ordered
            //values to the callback.
            //Default to [require, exports, module] if no deps
            deps = !deps.length && callback.length ? ['require', 'exports', 'module'] : deps;
            for (i = 0; i < deps.length; i += 1) {
                map = makeMap(deps[i], relName);
                depName = map.f;

                //Fast path CommonJS standard dependencies.
                if (depName === "require") {
                    args[i] = handlers.require(name);
                } else if (depName === "exports") {
                    //CommonJS module spec 1.1
                    args[i] = handlers.exports(name);
                    usingExports = true;
                } else if (depName === "module") {
                    //CommonJS module spec 1.1
                    cjsModule = args[i] = handlers.module(name);
                } else if (hasProp(defined, depName) ||
                           hasProp(waiting, depName) ||
                           hasProp(defining, depName)) {
                    args[i] = callDep(depName);
                } else if (map.p) {
                    map.p.load(map.n, makeRequire(relName, true), makeLoad(depName), {});
                    args[i] = defined[depName];
                } else {
                    throw new Error(name + ' missing ' + depName);
                }
            }

            ret = callback ? callback.apply(defined[name], args) : undefined;

            if (name) {
                //If setting exports via "module" is in play,
                //favor that over return value and exports. After that,
                //favor a non-undefined return value over exports use.
                if (cjsModule && cjsModule.exports !== undef &&
                        cjsModule.exports !== defined[name]) {
                    defined[name] = cjsModule.exports;
                } else if (ret !== undef || !usingExports) {
                    //Use the return value from the function.
                    defined[name] = ret;
                }
            }
        } else if (name) {
            //May just be an object definition for the module. Only
            //worry about defining if have a module name.
            defined[name] = callback;
        }
    };

    requirejs = require = req = function (deps, callback, relName, forceSync, alt) {
        if (typeof deps === "string") {
            if (handlers[deps]) {
                //callback in this case is really relName
                return handlers[deps](callback);
            }
            //Just return the module wanted. In this scenario, the
            //deps arg is the module name, and second arg (if passed)
            //is just the relName.
            //Normalize module name, if it contains . or ..
            return callDep(makeMap(deps, callback).f);
        } else if (!deps.splice) {
            //deps is a config object, not an array.
            config = deps;
            if (callback.splice) {
                //callback is an array, which means it is a dependency list.
                //Adjust args if there are dependencies
                deps = callback;
                callback = relName;
                relName = null;
            } else {
                deps = undef;
            }
        }

        //Support require(['a'])
        callback = callback || function () {};

        //If relName is a function, it is an errback handler,
        //so remove it.
        if (typeof relName === 'function') {
            relName = forceSync;
            forceSync = alt;
        }

        //Simulate async callback;
        if (forceSync) {
            main(undef, deps, callback, relName);
        } else {
            //Using a non-zero value because of concern for what old browsers
            //do, and latest browsers "upgrade" to 4 if lower value is used:
            //http://www.whatwg.org/specs/web-apps/current-work/multipage/timers.html#dom-windowtimers-settimeout:
            //If want a value immediately, use require('id') instead -- something
            //that works in almond on the global level, but not guaranteed and
            //unlikely to work in other AMD implementations.
            setTimeout(function () {
                main(undef, deps, callback, relName);
            }, 4);
        }

        return req;
    };

    /**
     * Just drops the config on the floor, but returns req in case
     * the config return value is used.
     */
    req.config = function (cfg) {
        config = cfg;
        if (config.deps) {
            req(config.deps, config.callback);
        }
        return req;
    };

    /**
     * Expose module registry for debugging and tooling
     */
    requirejs._defined = defined;

    define = function (name, deps, callback) {

        //This module may not have dependencies
        if (!deps.splice) {
            //deps is not an array, so probably means
            //an object literal or factory function for
            //the value. Adjust args.
            callback = deps;
            deps = [];
        }

        if (!hasProp(defined, name) && !hasProp(waiting, name)) {
            waiting[name] = [name, deps, callback];
        }
    };

    define.amd = {
        jQuery: true
    };
}());


var jam = {
    "packages": [
        {
            "name": "backbone",
            "location": "jam/backbone",
            "main": "backbone.js"
        },
        {
            "name": "jquery",
            "location": "jam/jquery",
            "main": "dist/jquery.js"
        },
        {
            "name": "lodash",
            "location": "jam/lodash",
            "main": "dist/lodash.compat.js"
        }
    ],
    "version": "0.2.17",
    "shim": {
        "backbone": {
            "deps": [
                "underscore",
                "jquery"
            ],
            "exports": "Backbone"
        }
    }
};

if (typeof require !== "undefined" && require.config) {
    require.config({
    "packages": [
        {
            "name": "backbone",
            "location": "jam/backbone",
            "main": "backbone.js"
        },
        {
            "name": "jquery",
            "location": "jam/jquery",
            "main": "dist/jquery.js"
        },
        {
            "name": "lodash",
            "location": "jam/lodash",
            "main": "dist/lodash.compat.js"
        }
    ],
    "shim": {
        "backbone": {
            "deps": [
                "underscore",
                "jquery"
            ],
            "exports": "Backbone"
        }
    }
});
}
else {
    var require = {
    "packages": [
        {
            "name": "backbone",
            "location": "jam/backbone",
            "main": "backbone.js"
        },
        {
            "name": "jquery",
            "location": "jam/jquery",
            "main": "dist/jquery.js"
        },
        {
            "name": "lodash",
            "location": "jam/lodash",
            "main": "dist/lodash.compat.js"
        }
    ],
    "shim": {
        "backbone": {
            "deps": [
                "underscore",
                "jquery"
            ],
            "exports": "Backbone"
        }
    }
};
}

if (typeof exports !== "undefined" && typeof module !== "undefined") {
    module.exports = jam;
};
define("../jam/require.config", function(){});

define('source/APP',[

	],
	function() {

		var APP = {};

		APP.init = function() {

		}

		APP.log = function(text) {
			console.log(text);
		}
		APP.getDataAsText = function(today) {

			//			var hh = today.getHours() > 12 ? today.getHours() - 12 : (today.getHours() < 10 ? "0" + today.getHours() : today.getHours());
			var hh = today.getHours();
			var min = today.getMinutes() < 10 ? "0" + today.getMinutes() : today.getMinutes();

			var dd = today.getDate();
			var mm = today.getMonth() + 1;
			var yyyy = today.getFullYear();

			if (dd < 10) {
				dd = '0' + dd
			}

			if (mm < 10) {
				mm = '0' + mm
			}

			var text = hh + ':' + min + '  ' + dd + '.' + mm + '.' + yyyy;
			return text;
		}
		return APP;

	});
define('templates/templates',[],function(){

this["JST"] = this["JST"] || {};

this["JST"]["category/edit.html"] = function(obj) {
obj || (obj = {});
var __t, __p = '', __e = _.escape;
with (obj) {
__p += '<div class="form-group">\r\n    <label for="inputName" class="col-xs-2 control-label">Name</label>\r\n    <div class="col-xs-8">\r\n        <input type="text" class="form-control categoryName" id="inputName" placeholder="Category name" value="' +
((__t = ( name )) == null ? '' : __t) +
'">\r\n    </div>\r\n</div>\r\n';

}
return __p
};

this["JST"]["category/list.html"] = function(obj) {
obj || (obj = {});
var __t, __p = '', __e = _.escape;
with (obj) {
__p += '<td class="name" style="font-size: 120%;">\r\n    ' +
((__t = (name )) == null ? '' : __t) +
'\r\n</td>\r\n\r\n\r\n<td>\r\n    <button type="button" class="btn btn-default edit btn-xs ">\r\n        <span class="glyphicon glyphicon-edit"></span>Edit</button>\r\n\r\n    <button type="button" class="btn btn-default remove btn-xs">\r\n        <span class="glyphicon glyphicon-remove"></span>Remove</button>\r\n</td>\r\n';

}
return __p
};

this["JST"]["category/main.html"] = function(obj) {
obj || (obj = {});
var __t, __p = '', __e = _.escape;
with (obj) {
__p += '<div>\r\n\r\n\r\n    <div class="mainCategory">\r\n        <br>\r\n        <!--         <h2>Category</h2>\r\n -->\r\n        <div class="panel myPanelStyle">\r\n\r\n            <div class="panel-heading">\r\n                <button type="button" class="btn btn-primary" id=\'addCategoryBtn\'>\r\n                    <span class="glyphicon glyphicon-plus"></span>Add new category</button>\r\n            </div>\r\n\r\n            <table class="table table-hover categoryTable">\r\n                <thead>\r\n                    <tr>\r\n                        <th>Name</th>\r\n                        <th style="width:180px;">Options</th>\r\n                    </tr>\r\n                </thead>\r\n\r\n            </table>\r\n        </div>\r\n\r\n\r\n\r\n    </div>\r\n\r\n\r\n\r\n\r\n    <div class="editCategory">\r\n        <br>\r\n        <div class="panel myPanelStyle">\r\n\r\n            <div class="panel-heading">\r\n                <h3 class="editCategoryHeader">Edit category</h3>\r\n            </div>\r\n            <br>\r\n            <form class="form-horizontal" role="form">\r\n                <div class="formContent">\r\n\r\n\r\n                </div>\r\n\r\n                <div class="form-group">\r\n                    <div class="class= col-sm-offset-1 col-sm-11">\r\n                        <button type="button" class="btn btn-primary saveBtn ">Save</button>\r\n                        <button type="button" class="btn btn-default closeBtn">Close</button>\r\n                    </div>\r\n\r\n                </div>\r\n\r\n            </form>\r\n        </div>\r\n\r\n    </div>\r\n\r\n    <!--     <div class="editCategory">\r\n\r\n        <h2 class="editCategoryHeader">Edit category</h2>\r\n\r\n\r\n        <form class="form-horizontal" role="form">\r\n            <div class="formContent">\r\n\r\n\r\n            </div>\r\n\r\n            <div class="form-group">\r\n                <div class="class= col-sm-offset-1 col-sm-11">\r\n                    <button type="button " class="btn btn-primary saveBtn ">Save</button>\r\n                    <button type="button " class="btn btn-default closeBtn">Close</button>\r\n                </div>\r\n\r\n            </div>\r\n\r\n        </form>\r\n\r\n\r\n    </div> -->\r\n\r\n\r\n\r\n</div>\r\n';

}
return __p
};

this["JST"]["category/selectList.html"] = function(obj) {
obj || (obj = {});
var __t, __p = '', __e = _.escape, __j = Array.prototype.join;
function print() { __p += __j.call(arguments, '') }
with (obj) {

 for(var i=0;i<tab.length;i++ ){ ;
__p += '\r\n\r\n\r\n\t\t<div class="categoryChooseItem" value="';
 print(tab[i].id) ;
__p += '" style="width:90%; margin-top: 10px;font-size: 120%" >\r\n\t\t\t<div class="categoryNameList" style="float: left;padding-top: 4px"> ';
 print(tab[i].name) ;
__p += '</div> \t\t\t\r\n\t\t\t<div style="float: right;">\t\t\t\t\t\t\r\n\t\t\t\t<button  type="button"  value="';
 print(tab[i].id) ;
__p += '" class="btn btn-primary selectBtn" >Select</button>\r\n\t\t\t</div>\r\n\t\t\t<div class="clearfix">\r\n\t\t\t</div>\r\n\r\n\t\t</div>\r\n \r\n';
 } ;
__p += '\r\n\r\n';

}
return __p
};

this["JST"]["dish/categoryCheckbox.html"] = function(obj) {
obj || (obj = {});
var __t, __p = '', __e = _.escape, __j = Array.prototype.join;
function print() { __p += __j.call(arguments, '') }
with (obj) {
__p += '\r\n\r\n';
 _.each(cat,function(c){    ;
__p += '\r\n<div class="input-group">\r\n    <span class="input-group-addon">\r\n        <input class="categoryCheck" type="checkbox" value="';
 print(c.idx) ;
__p += '" ';
 if(c.check===true){print('checked');  } ;
__p += '  >\r\n    </span>\r\n    <label class="form-control"> ';
 print(c.name); ;
__p += ' </label>\r\n</div>\r\n\r\n\r\n';
 });    ;
__p += '\r\n';

}
return __p
};

this["JST"]["dish/edit.html"] = function(obj) {
obj || (obj = {});
var __t, __p = '', __e = _.escape;
with (obj) {
__p += '<div class="form-group">\r\n    <label for="inputName" class="col-xs-2 control-label">Name</label>\r\n    <div class="col-xs-8">\r\n        <input type="text" class="form-control dishName" id="inputName" placeholder="Dish name" value="' +
((__t = ( name )) == null ? '' : __t) +
'">\r\n    </div>\r\n</div>\r\n\r\n<div class="form-group">\r\n    <label for="inputName" class=" col-xs-2 control-label">Category</label>\r\n    <div class="container col-xs-8 categoryList">\r\n\r\n\r\n\r\n\r\n\r\n\r\n    </div>\r\n</div>\r\n';

}
return __p
};

this["JST"]["dish/list.html"] = function(obj) {
obj || (obj = {});
var __t, __p = '', __e = _.escape;
with (obj) {
__p += '\r\n   \r\n    <td class="name" style="font-size: 120%;"> ' +
((__t = ( name )) == null ? '' : __t) +
'</td>\r\n   \r\n\r\n    <td>\r\n        <button type="button" class="btn btn-default edit btn-xs ">\r\n            <span class="glyphicon glyphicon-edit"></span>Edit</button>\r\n        <button type="button" class="btn btn-default remove btn-xs">\r\n            <span class="glyphicon glyphicon-remove"></span>Remove</button>\r\n    </td> \r\n ';

}
return __p
};

this["JST"]["dish/main.html"] = function(obj) {
obj || (obj = {});
var __t, __p = '', __e = _.escape;
with (obj) {
__p += '<div class="mainDish">\r\n    <br>\r\n\r\n    <div class="panel myPanelStyle">\r\n\r\n        <div class="panel-heading">\r\n            <button type="button" class="btn btn-primary" id=\'addDishBtn\'>\r\n                <span class="glyphicon glyphicon-plus"></span>Add new dish</button>\r\n        </div>\r\n\r\n        <table class="table table-hover dishTable">\r\n            <thead>\r\n                <tr>\r\n\r\n                    <th>Name</th>\r\n\r\n                    <th style="width:180px;">Options</th>\r\n\r\n                </tr>\r\n            </thead>\r\n\r\n        </table>\r\n    </div>\r\n\r\n\r\n\r\n\r\n</div>\r\n\r\n\r\n\r\n<div class="editDish">\r\n\r\n\r\n\r\n    <br>\r\n    <div class="panel myPanelStyle">\r\n\r\n        <div class="panel-heading">\r\n            <h3 class="editDishHeader">Edit dish</h3>\r\n        </div>\r\n        <br>\r\n        <form class="form-horizontal" role="form">\r\n            <div class="formContent">\r\n            </div>\r\n\r\n            <div class="form-group">\r\n                <div class="class= col-sm-offset-1 col-sm-7">\r\n                    <button type="button" class="btn btn-primary saveBtn">Save</button>\r\n                    <button type="button" class="btn btn-default closeBtn">Close</button>\r\n                </div>\r\n\r\n            </div>\r\n\r\n        </form>\r\n    </div>\r\n\r\n\r\n\r\n\r\n</div>\r\n';

}
return __p
};

this["JST"]["dish/selectList.html"] = function(obj) {
obj || (obj = {});
var __t, __p = '', __e = _.escape, __j = Array.prototype.join;
function print() { __p += __j.call(arguments, '') }
with (obj) {

 for(var i=0;i<tab.length;i++ ){ ;
__p += '\r\n\t<!--\r\n\t\t<div class="row" style="margin-top: 20px;">\r\n\t\t\t<div class="col-xs-9">';
 print(tab[i].name) ;
__p += '  ';
 print(tab[i].id) ;
__p += ' </div>\r\n\t\t\t<div class="col-xs-3">\r\n\t\t\t\t<button  type="button" class="btn btn-primary selectBtn" >Select</button>\r\n\t\t\t</div>\r\n\t\t<div>\r\n\t-->\r\n\r\n\t\t<div class="dishChooseItem" value="';
 print(tab[i].id) ;
__p += '" style="width:90%; margin-top: 10px;font-size: 120%" >\r\n\t\t\t<div class="dishNameList" style="float: left;padding-top: 4px"> ';
 print(tab[i].name) ;
__p += '</div> \t\t\t\r\n\t\t\t<div style="float: right;">\t\t\t\t\t\t\r\n\t\t\t\t<button  type="button" id="AL" value="';
 print(tab[i].id) ;
__p += '" class="btn btn-primary selectBtn" >Select</button>\r\n\t\t\t</div>\r\n\t\t\t<div class="clearfix">\r\n\t\t\t</div>\r\n\r\n\t\t</div>\r\n\r\n';
 } ;
__p += '\r\n\r\n';

}
return __p
};

this["JST"]["globalResult/globalResult.html"] = function(obj) {
obj || (obj = {});
var __t, __p = '', __e = _.escape, __j = Array.prototype.join;
function print() { __p += __j.call(arguments, '') }
with (obj) {
__p += '<div class="CSSTableGenerator">\r\n\r\n\r\n    <table class="globalResultTable">\r\n        <tr>\r\n            <td>\r\n                #\r\n            </td>\r\n             <td>\r\n                Name\r\n            </td>\r\n            <td>\r\n                Points\r\n            </td>\r\n            <td>\r\n                Stage\r\n            </td>\r\n\r\n        </tr>\r\n\r\n\r\n';
 for(var i=0;i<tab.length;i++ ){ ;
__p += '\r\n\r\n\r\n        <tr> \r\n            <td>\r\n               ';
 print((i+1)) ;
__p += '\r\n            </td>\r\n            <td>\r\n               ';
 print(tab[i].name) ;
__p += '\r\n            </td>\r\n            <td>\r\n               ';
 print(tab[i].points) ;
__p += '\r\n            </td>\r\n            <td>\r\n                ';
 print(tab[i].stage) ;
__p += '\r\n            </td>\r\n\r\n        </tr>\r\n\r\n';
 } ;
__p += '\r\n\r\n    </table>\r\n\r\n<div style="text-align: left;font-size: 70%">\r\nLast update:<span class="updateData" style="margin-left: 10px "></span>\r\n</div>\r\n</div>\r\n\r\n\r\n';

}
return __p
};

this["JST"]["localResult/localResult.html"] = function(obj) {
obj || (obj = {});
var __t, __p = '', __e = _.escape, __j = Array.prototype.join;
function print() { __p += __j.call(arguments, '') }
with (obj) {
__p += '<div class="CSSTableGenerator">\r\n    <table class="localResultTable">\r\n        <tr>\r\n            <td>\r\n                #\r\n            </td>\r\n\r\n            <td>\r\n                Points\r\n            </td>\r\n            <td>\r\n                Stage\r\n            </td>\r\n\r\n        </tr>\r\n\r\n\r\n';
 for(var i=0;i<tab.length;i++ ){ ;
__p += '\r\n\r\n\r\n        <tr>\r\n            <td>\r\n               ';
 print((i+1)) ;
__p += '\r\n            </td>\r\n\r\n            <td>\r\n               ';
 print(tab[i].points) ;
__p += '\r\n            </td>\r\n            <td>\r\n                ';
 print(tab[i].stage) ;
__p += '\r\n            </td>\r\n\r\n        </tr>\r\n\r\n';
 } ;
__p += '\r\n\r\n    </table>\r\n</div>\r\n\r\n\r\n';

}
return __p
};

this["JST"]["main/main.html"] = function(obj) {
obj || (obj = {});
var __t, __p = '', __e = _.escape;
with (obj) {
__p += '<div class="frame mainFrame" style="display:none">\r\n\r\n\r\n    <div class="menu">\r\n\r\n        <div class="title">Math Skills Test</div>\r\n        <br>\r\n        <div style="text-align: center ;">\r\n            <button class="menuButton StartGameID" type="button">Start game</button>\r\n        </div>\r\n        \r\n        <div style="min-height: 20px"></div>\r\n\r\n         <div style="text-align: center ;">\r\n            <button class="menuButton" type="button" data-toggle="collapse" data-parent="#accordion" href="#collapseRules">Game Rules</button>\r\n        </div>\r\n          <div style="min-height: 20px"></div>\r\n        <div id="collapseRules" class="panel-collapse collapse" >\r\n         <div style="min-height: 20px"></div>\r\n            <div style="width:70%;margin: auto;text-align:justify;" >\r\n                You get a math question and 4 possible answers, you have only 5 second to chose right answer. If you give the correct answer, you go to next stage. For every completed stage you will get 100 points, for any unused time you can get another 50 points.\r\n            </div>\r\n <div style="min-height: 30px"></div>\r\n\r\n        </div>\r\n\r\n\r\n         <div style="text-align: center ;">\r\n            <button class="menuButton" type="button" data-toggle="collapse" data-parent="#accordion" href="#collapseOne">Result table</button>\r\n        </div>\r\n          <div style="min-height: 20px"></div>\r\n\r\n<!--\r\n        <div class="title" style="font-size: 100%">\r\n            <a data-toggle="collapse" data-parent="#accordion" href="#collapseOne">Results table</a>\r\n        </div>\r\n-->\r\n        <div id="collapseOne" class="panel-collapse collapse">\r\n            <div class="resultTable">\r\n\r\n\r\n                <ul class="nav nav-tabs" >\r\n                    \r\n                    <li class="active"><a href="#local" data-toggle="tab">Local</a>\r\n                    </li>\r\n                    <li><a href="#global" data-toggle="tab">Global</a>\r\n                    </li>\r\n\r\n                </ul>\r\n\r\n                <!-- Tab panes -->\r\n                <div class="tab-content">\r\n                    <div class="tab-pane fade in active" id="local">\r\n\r\n                        <div class="localResult">\r\n                        </div>\r\n\r\n                    </div>\r\n                    <div class="tab-pane fade" id="global">\r\n                        \r\n                        <div class="globalResult">\r\n                        </div>\r\n\r\n                    </div>\r\n\r\n                </div>\r\n\r\n            </div>\r\n            <br>\r\n        </div>\r\n\r\n\r\n    </div>\r\n\r\n</div>\r\n\r\n\r\n<div class="frame gameFrame">\r\n    <table style="width:100%;height: 100%; text-align: center">\r\n        <tr style="min-height: 33%">\r\n            <td>\r\n\r\n                <div class="textLable" style="text-align: left;margin-left: 10%">Points:\r\n                    <span class="pointsID"></span>\r\n                    <br>Stage:\r\n                    <span class="stageID"></span>\r\n\r\n                </div>\r\n            </td>\r\n            <td>\r\n                <button class="menuButton2 topID answerButton" style="" type="button">top</button>\r\n            </td>\r\n            <td>\r\n                <div class="textLable" style="text-align: left;margin-left: 30%">Time:\r\n                    <span class="timeID"></span>\r\n                </div>\r\n            </td>\r\n        </tr>\r\n\r\n        <tr>\r\n            <td style="width:33%">\r\n                <button class="menuButton2 leftID answerButton" style="" type="button">left</button>\r\n            </td>\r\n            <td style="width:34%">\r\n\r\n                <div class="normalGameCenter">\r\n                    <div class="QuastionID"></div>\r\n                </div>\r\n\r\n                <div class="finishGameCenter">\r\n                    <div class="QuastionID"></div>\r\n                    <div class="failTypeID"></div>\r\n\r\n                </div>\r\n\r\n\r\n\r\n            </td>\r\n            <td style="width:33%">\r\n                <button class="menuButton2 rightID answerButton" style="" type="button">right</button>\r\n            </td>\r\n        </tr>\r\n\r\n        <tr>\r\n            <td>\r\n                <div class="finishGameCenter">\r\n                    <button class="menuButton3 RepeatID" style="" type="button">Repeat</button>\r\n                </div>\r\n            </td>\r\n            <td>\r\n                <button class="menuButton2 bottomID answerButton" style="" type="button">bottom</button>\r\n            </td>\r\n            <td>\r\n                <div class="finishGameCenter">\r\n                    <button class="menuButton3 MenuID" style="" type="button">Menu</button>\r\n                </div>\r\n            </td>\r\n        </tr>\r\n\r\n    </table>\r\n\r\n</div>\r\n\r\n\r\n\r\n<div class="modal fade " id="nameModal" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">\r\n    <div class="modal-dialog modal-lg" style="font-size: 80%">\r\n        <div class="modal-content backgroundGradient">\r\n            <div class="modal-header" style="text-align: center">\r\n                <h4 class="modal-title" id="myModalLabel" style="font-size:250%">New Record</h4>\r\n                <h4 class="modal-title pointsModal" id="myModalLabel"></h4>\r\n            </div>\r\n\r\n            <div class="modal-body ">\r\n\r\n                <div class="form-group has-success has-feedback">\r\n    \r\n                 <label for="inputName" class=" control-label" style="font-size:150%">Player Name</label>\r\n                                <input type="text " class="form-control playerName " id="inputName" placeholder="" value="">\r\n                                \r\n<!--\r\n                       <label for="inputName" class="col-xs-4 control-label" >Player Name</label>\r\n                            <div class="col-xs-7 ">\r\n                                <input type="text " class="form-control playerName " id="inputName" placeholder="" value="">\r\n                               \r\n                            </div>\r\n\r\n                        </div>\r\n-->             \r\n                </div>\r\n\r\n                 <div class="modal-footer ">                \r\n                   <button type="button" class="btn btn-primary confirmName menuButton">Send</button>\r\n                </div>\r\n            </div>\r\n        </div>\r\n    </div>\r\n</div>\r\n\r\n\r\n<div class="modal fade " id="alertModal" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">\r\n      <div class="modal-dialog modal-lg" style="font-size: 80%">\r\n        <div class="modal-content backgroundGradient">\r\n            <div class="modal-header" style="text-align: center">\r\n                <h4 class="modal-title" id="myModalLabel" style="font-size:200%">Network error</h4>\r\n            </div>\r\n\r\n            <div class="modal-body ">\r\n            Check your internet connection.\r\n\r\n                 <div class="modal-footer ">                \r\n                   <button type="button" class="btn btn-primary closeAlerDialog menuButton">Close</button>\r\n                </div>\r\n            </div>\r\n        </div>\r\n    </div>\r\n</div>\r\n';

}
return __p
};

this["JST"]["plan/list.html"] = function(obj) {
obj || (obj = {});
var __t, __p = '', __e = _.escape;
with (obj) {
__p += '<td class="dayDesc"style="vertical-align:middle;;font-size: 90%">\r\n\t<b>' +
((__t = ( day )) == null ? '' : __t) +
'</b>\r\n</td>\r\n<td class="data dayDesc dishNameLabel " style="vertical-align:middle;font-size: 90%">\r\n    ' +
((__t = ( dataText)) == null ? '' : __t) +
'\r\n</td>\r\n<td class="name dayDesc"style="vertical-align:middle;font-size: 120%;" >\r\n    ' +
((__t = ( dishName )) == null ? '' : __t) +
'\r\n</td>\r\n<td>\r\n    <button type="button" class="btn btn-default draw btn-xs ">\r\n        <span class="glyphicon glyphicon-random"> </span> Draw</button>\r\n\r\n    <button type="button" class="btn btn-default choose btn-xs">\r\n        <span class="glyphicon glyphicon-search"> </span>Choose</button>\r\n    <button type="button" class="btn btn-default clear btn-xs">\r\n        <span class="glyphicon glyphicon-remove"> </span>Clear</button>\r\n</td>\r\n';

}
return __p
};

this["JST"]["plan/main.html"] = function(obj) {
obj || (obj = {});
var __t, __p = '', __e = _.escape;
with (obj) {
__p += '<div class="mainPlan">\r\n<br>\r\n    <div class="row ">\r\n\r\n\r\n        <div class="col-xs-12">\r\n\r\n            <div class="panel myPanelStyle">\r\n\r\n                <div class="panel-heading">\r\n\r\n                    <div class="container-fluid">\r\n\r\n                        <div class="row ">\r\n                            <div style="float: left">\r\n\r\n                                <button type="button" class="btn btn-default btn-lg back">\r\n                                    <span class="glyphicon glyphicon-circle-arrow-left"></span>\r\n                                </button>\r\n                            </div>\r\n\r\n                            <div style="float: left;margin-left:20px ">\r\n                                <h4>\r\n                                    <b>Week</b>\r\n                                </h4>\r\n                            </div>\r\n\r\n\r\n                            <div style="float: right">\r\n\r\n                                <button type="button" class="btn btn-default btn-lg next">\r\n                                    <span class="glyphicon glyphicon-circle-arrow-right"></span>\r\n                                </button>\r\n                            </div>\r\n\r\n                            \r\n\r\n                        </div>\r\n                    </div>\r\n                </div>\r\n\r\n                <div>\r\n                    <table class="table table-hover planTable" >\r\n                        <thead>\r\n                            <tr >\r\n                                <th style="width:1%;">#</th>\r\n                                <th style="width:4%">Data</th> \r\n                                <th >Dish</th>\r\n                                <th style="width:240px;">Options</th>\r\n                            </tr>\r\n\r\n                        </thead>\r\n                        <tbody class="dayRow">\r\n\r\n\r\n                        </tbody>\r\n\r\n\r\n                    </table>\r\n\r\n                </div>\r\n\r\n            </div>\r\n\r\n        </div>\r\n\r\n\r\n\r\n\r\n\r\n    </div>\r\n';

}
return __p
};

this["JST"]["rules/edit.html"] = function(obj) {
obj || (obj = {});
var __t, __p = '', __e = _.escape;
with (obj) {
__p += '<div class="form-group">\r\n    <label for="inputName" class="col-xs-3 control-label">Category 1</label>\r\n    <div class="col-xs-5">\r\n        <input type="text" class="form-control categoryName1" id="inputName" placeholder="Category name" value="' +
((__t = ( cat1Name )) == null ? '' : __t) +
'">         \r\n    </div>\r\n    <button type="button" class="btn btn-default chooseCat1"> <span class="glyphicon glyphicon-search"> </span> Choose</button>\r\n</div>\r\n\r\n<div class="form-group">\r\n    <label for="inputName" class="col-xs-3 control-label">Category 2</label>\r\n    <div class="col-xs-5">\r\n        <input type="text" class="form-control categoryName2" id="inputName" placeholder="Category name" value="' +
((__t = ( cat2Name )) == null ? '' : __t) +
'">\r\n    </div>\r\n    <button type="button" class="btn btn-default chooseCat2"> <span class="glyphicon glyphicon-search"> </span> Choose</button>\r\n</div>\r\n\r\n<div class="form-group">\r\n    <label for="howOftenOneDish" class="col-xs-3 control-label">Minimal gap between the dishes</label>\r\n    <div class="col-xs-5">\r\n        <input type="number" class="form-control" id="howOftenOneDish" value="' +
((__t = ( numOfDay )) == null ? '' : __t) +
'">\r\n    </div>\r\n</div>\r\n';

}
return __p
};

this["JST"]["rules/list.html"] = function(obj) {
obj || (obj = {});
var __t, __p = '', __e = _.escape;
with (obj) {
__p += '<td class="dayDesc"style="vertical-align:middle;">\r\n\t<b>' +
((__t = ( cat1Name )) == null ? '' : __t) +
'</b>\r\n</td>\r\n\r\n<td class="dayDesc"style="vertical-align:middle;">\r\n\t<b>' +
((__t = ( cat2Name )) == null ? '' : __t) +
'</b>\r\n</td>\r\n\r\n<td class="dayDesc"style="vertical-align:middle;">\r\n\t<b>' +
((__t = ( numOfDay )) == null ? '' : __t) +
'</b>\r\n</td>\r\n\r\n<td>\r\n\r\n    <button type="button" class="btn btn-default edit btn-xs">\r\n        <span class="glyphicon glyphicon-edit"> </span>Edit</button>\r\n    <button type="button" class="btn btn-default remove btn-xs">\r\n        <span class="glyphicon glyphicon-remove"> </span>Remove</button>\r\n</td>\r\n';

}
return __p
};

this["JST"]["rules/main.html"] = function(obj) {
obj || (obj = {});
var __t, __p = '', __e = _.escape;
with (obj) {
__p += '<div class="mainRules">\r\n    <br>\r\n    <div class="row ">\r\n\r\n\r\n        <div class="col-xs-12">\r\n\r\n            <div class="panel myPanelStyle">\r\n\r\n                <div class="panel-heading">\r\n\r\n                <h4><b>Rules</b></h4>\r\n                </div>\r\n                <br>\r\n\r\n\r\n                <br>\r\n                <div class="container">\r\n                    <div class="row ">\r\n                        <div class="col-xs-12">\r\n                            <label>Category dependances</label>\r\n                            <br>\r\n                            <button type="button" class="btn btn-primary" id=\'addRuleBtn\'>\r\n                                <span class="glyphicon glyphicon-plus"></span>Add new rule</button>\r\n\r\n                            <table class="table table-hover ruleTable" style="width:98%">\r\n                                <thead>\r\n                                    <tr>\r\n                                        <th class="makeSmaller1">Category 1</th>\r\n                                        <th class="makeSmaller1">Category 2</th>\r\n                                        <th>Break</th>\r\n                                        <th >Options</th>\r\n                                    </tr>\r\n                                </thead>\r\n                            </table>\r\n                            <br>\r\n                        </div>\r\n                    </div>\r\n                </div>\r\n\r\n\r\n\r\n            </div>\r\n\r\n        </div>\r\n    </div>\r\n</div>\r\n\r\n\r\n<div class="editRule">\r\n\r\n\r\n\r\n    <br>\r\n    <div class="panel myPanelStyle">\r\n\r\n        <div class="panel-heading">\r\n            <h3 class="editRuleHeader">Edit rule</h3>\r\n        </div>\r\n        <br>\r\n        <form class="form-horizontal" role="form">\r\n\r\n\r\n\r\n            <div class="formContent">\r\n            </div>\r\n\r\n\r\n\r\n\r\n            <div class="form-group">\r\n                <div class="class= col-sm-offset-2 col-xs-7">\r\n                    <button type="button" class="btn btn-primary saveBtn ">Save</button>\r\n                    <button type="button" class="btn btn-default closeBtn">Close</button>\r\n                </div>\r\n\r\n            </div>\r\n\r\n        </form>\r\n    </div>\r\n\r\n\r\n\r\n\r\n</div>\r\n';

}
return __p
};

  return this["JST"];

});
define('source/Question',[

	],
	function() {

		var rand = function() {
			return Math.floor(Math.random() * 100000);
		};

		var Question = Backbone.Model.extend({
			m_iNum: 0,
			m_sQuestion: 0,
			m_sLeft: 0,
			m_sRight: 0,
			m_sTop: 0,
			m_sBottom: 0,
			m_fTime: 0,
			m_eCorrectAnswer: 0, // t=0,b,l,r
			m_tText: null,
			//std::string m_tText[4];
			constructor: function(arg) {
				Backbone.Model.apply(this, arguments);
				this.m_tText = [];
			},
			rand: function() {
				return Math.floor(Math.random() * 100000);
			},

			Generate: function() {
				var tab = [];
				tab.push(0);
				tab.push(1);
				tab.push(2);
				tab.push(3);

				var r = this.rand();
				r = r % (tab.length);

				this.m_sLeft = this.m_tText[tab[r]];
				if (tab[r] == 0)
					this.m_eCorrectAnswer = 2;
				tab.splice(r, 1);
				//////////////////////////////////
				r = this.rand() % (tab.length);
				this.m_sRight = this.m_tText[tab[r]];
				if (tab[r] == 0)
					this.m_eCorrectAnswer = 3;
				tab.splice(r, 1);
				//////////////////////////////////
				r = this.rand() % (tab.length);
				this.m_sTop = this.m_tText[tab[r]];
				if (tab[r] == 0)
					this.m_eCorrectAnswer = 0;
				tab.splice(r, 1);
				//////////////////////////////////
				r = this.rand() % (tab.length);
				this.m_sBottom = this.m_tText[tab[r]];
				if (tab[r] == 0)
					this.m_eCorrectAnswer = 1;
				tab.splice(r, 1);
			}

		});

		var CSimpleQuestion = Question.extend({

			constructor: function(arg) {
				Question.apply(this, arguments);
				this.m_iNum = arg;

			},

			Generate: function() {

				console.log("simple " + this.m_iNum);
				var dzialanie = rand() % (this.m_iNum);

				var a = (rand() % 9) + 1;
				var b = (rand() % 9) + 1;;

				var c;

				var znak;
				if (dzialanie == 0) //dodawanie
				{
					c = a + b;
					znak = '+';
				}
				if (dzialanie == 1) //odejmowanie
				{
					c = a - b;
					znak = '-';

				}
				if (dzialanie == 2) //mnozenie
				{
					c = a * b;
					znak = '*';

				}
				if (dzialanie == 3) //dzielenie
				{
					c = a / b;
					znak = '/';
				}

				var buf = a + ' ' + znak + ' ' + b;

				this.m_sQuestion = buf;

				this.m_tText[0] = c;

				this.m_tText[1] = (c + (rand() % 12) + 1);

				this.m_tText[2] = ((c + (rand() % 6) + 1));

				this.m_tText[3] = ((c - ((rand() % 3) + 1)));

				Question.prototype.Generate.apply(this, arguments);

			}

		});

		var randMinus = function() {
			//ujemna
			if ((rand() % 2) == 0) {
				return -1;
			} else {
				return 1;
			}

		}

		var CHardQuestion = Question.extend({

			constructor: function(arg) {
				Question.apply(this, arguments);
				this.m_iNum = arg;
			},

			Generate: function() {
				console.log("hard " + this.m_iNum);
				var dzialanie = rand() % (this.m_iNum);

				var a, b;
				a = b = 0;

				//od 5 do 10 , albo plus albo minus
				while (a == 0)
					a = (5 + (rand() % 6)) * randMinus();

				//od 5 do 10 , albo plus albo minus
				while (b == 0 || b == a)
					b = (5 + (rand() % 6)) * randMinus();

				var c;

				var znak;
				if (dzialanie == 0) //dodawanie
				{
					c = a + b;
					znak = '+';
				}
				if (dzialanie == 1) //odejmowanie
				{
					c = a - b;
					znak = '-';

				}
				if (dzialanie == 2) //mnozenie
				{
					b = (rand() % 7) + 3;;
					c = a * b;
					znak = '*';

				}
				if (dzialanie == 3) //dzielenie
				{
					c = a / b;
					znak = '/';
				}

				var buf = a + ' ' + znak + ' ' + b;

				this.m_sQuestion = buf;

				this.m_tText[0] = c;

				this.m_tText[1] = (c + (rand() % 12) + 1);

				this.m_tText[2] = ((c + (rand() % 6) + 1));

				this.m_tText[3] = ((c - ((rand() % 3) + 1)));

				Question.prototype.Generate.apply(this, arguments);

			}

		});

		var CVeryHardQuestion = Question.extend({

			constructor: function(arg) {
				Question.apply(this, arguments);
				this.m_iNum = arg;
			},

			Generate: function() {
				console.log("very hard " + this.m_iNum);
				var dzialanie = rand() % (this.m_iNum);

				var a, b;
				a = b = 0;

				//od 7 do 13 , albo plus albo minus
				while (a == 0)
					a = (7 + (rand() % 7)) * randMinus();

				//od 4 do 14 , albo plus albo minus
				while (b == 0 || b == a)
					b = (4 + (rand() % 11)) * randMinus();

				console.log(a + "  " + b);
				var c;

				var znak;
				if (dzialanie == 0) //dodawanie
				{
					c = a + b;
					znak = '+';
				}
				if (dzialanie == 1) //odejmowanie
				{
					c = a - b;
					znak = '-';

				}
				if (dzialanie == 2) //mnozenie
				{
					b = (rand() % 14) - 7;;
					c = a * b;
					znak = '*';
				}
				if (dzialanie == 3) //dzielenie
				{
					c = a / b;
					znak = '/';
				}

				var buf = a + ' ' + znak + ' ' + b;

				this.m_sQuestion = buf;

				this.m_tText[0] = c;

				this.m_tText[1] = (c + (rand() % 12) + 1);

				this.m_tText[2] = ((c + (rand() % 6) + 1));

				this.m_tText[3] = ((c - ((rand() % 3) + 1)));

				Question.prototype.Generate.apply(this, arguments);

			}

		});

		return {
			simple: CSimpleQuestion,
			hard: CHardQuestion,
			veryHard: CVeryHardQuestion,

		};

	});
define('source/views/localResult/main',[

        'templates/templates',
        'source/APP'

    ],
    function(templates, APP) {
        var This;

        var LocalResultView = Backbone.View.extend({
            tagName: "div",
            events: {

            },

            initialize: function() {
                This = this;
                Backbone.View.prototype.initialize.apply(this, arguments);
                //                 this.$el.html(templates['localResult/localResult.html']);
                //                this.listenTo(APP.localResultCollection, 'add', this.onAddResult);
                this.listenTo(APP.localResultCollection, 'add', this.onChange);
                //this.listenTo(APP.localResultCollection, 'remove', this.onChange);
                this.render();

            },
            onChange: function() {
                this.render();
            },

            /*            onAddResult: function(model) {

                var view = new ResultView({
                    'model': model
                });
                this.$el.find('.localResultTable').append(view.$el);
                model.save();
            },
            */
            render: function() {
                var list = [];

                for (var i = 0; i < APP.localResultCollection.length; i++) {
                    var obj = {};
                    obj.points = APP.localResultCollection.at(i).get('points');
                    obj.stage = APP.localResultCollection.at(i).get('stage');

                    list.push(obj);
                }

                /*                var o = {
                    points: 1212,
                    stage: 2
                };
                list.push(o);*/

                this.$el.html(templates['localResult/localResult.html']({
                    tab: list
                }));

                return this;
            },

        });
        return LocalResultView;

    });
define('source/models/localResult',[

	],
	function() {
		var LocalResult = Backbone.Model.extend({
			defaults: {
				points: 0,
				stage: 0,
				idx: 0
			},
			url: 'LocalResult',

			initialize: function() {},

		});
		return LocalResult;

	});
define('source/collections/localResult',[
		'source/models/localResult'
	],
	function(LocalResult) {
		var LocalResultCollection = Backbone.Collection.extend({
			events: {

			},

			model: LocalResult,
			localStorage: new Backbone.LocalStorage("LocalResultCollection"),
			//			comparator: 'points'
			comparator: function(a, b) {
				var aa = a.get('points');
				var bb = b.get('points');

				if (aa != bb) {
					if (aa < bb) {
						return 1;
					} else {
						return -1;
					}

				}

				if (a.get('stage') > b.get('stage')) {
					return 1;
				} else {
					return -1;
				}
				return 0;

			},
			getNextID: function() {
				var id = 0;
				for (var i = 0; i < this.length; i++) {
					var idx = this.at(i).get('idx');
					if (idx > id) {
						id = idx;
					}
				}
				id++;
				return id;
			},

		});
		return LocalResultCollection;

	});
define('source/views/globalResult/main',[

        'templates/templates',
        'source/APP'

    ],
    function(templates, APP) {
        var This;

        var GlobalResultView = Backbone.View.extend({
            tagName: "div",
            events: {

            },

            initialize: function() {
                This = this;
                Backbone.View.prototype.initialize.apply(this, arguments);
                this.listenTo(APP.globalResultCollection, 'add', this.onChange);
                this.render();

            },
            onChange: function() {
                this.render();
            },

            render: function() {
                var list = [];

                for (var i = 0; i < APP.globalResultCollection.length; i++) {
                    var obj = {};
                    obj.points = APP.globalResultCollection.at(i).get('points');
                    obj.stage = APP.globalResultCollection.at(i).get('stage');
                    obj.name = APP.globalResultCollection.at(i).get('name');

                    list.push(obj);
                }

                this.$el.html(templates['globalResult/globalResult.html']({
                    tab: list
                }));

                var data = APP.optionsCollection.at(0).get("updateData");
                $(".updateData").html(data);
                return this;
            },

        });
        return GlobalResultView;

    });
define('source/models/globalResult',[

	],
	function() {
		var GlobalResult = Backbone.Model.extend({
			defaults: {
				name: "",
				points: 0,
				stage: 0,
				idx: 0
			},
			url: 'GlobalResult',

			initialize: function() {},

		});
		return GlobalResult;

	});
define('source/collections/globalResult',[
		'source/models/globalResult'
	],
	function(GlobalResult) {
		var GlobalResultCollection = Backbone.Collection.extend({
			events: {

			},

			model: GlobalResult,
			localStorage: new Backbone.LocalStorage("GlobalResultCollection"),
			//			comparator: 'points'
			comparator: function(a, b) {

				var aa = a.get('points');
				var bb = b.get('points');
			
				if (aa != bb) {
					if (aa < bb) {
						return 1;
					} else {
						return -1;
					}

				}

				if (a.get('stage') > b.get('stage')) {
					return 1;
				} else {
					return -1;
				}
				return 0;

			},
		getNextID: function() {
			var id = 0;
			for (var i = 0; i < this.length; i++) {
				var idx = this.at(i).get('idx');
				if (idx > id) {
					id = idx;
				}
			}
			id++;
			return id;
		},
		});
		return GlobalResultCollection;

	});
define('source/models/options',[

	],
	function() {
		var Options = Backbone.Model.extend({
			defaults: {
				updateData: null,
				name: "Player",
				idx: 0

			},
			url: 'Options',

			initialize: function() {},

		});
		return Options;

	});
define('source/collections/options',[
		'source/models/options'
	],
	function(Options) {
		var OptionsCollection = Backbone.Collection.extend({

			model: Options,
			localStorage: new Backbone.LocalStorage("OptionsCollection"),

			getNextID: function() {
				var id = 0;
				for (var i = 0; i < this.length; i++) {
					var idx = this.at(i).get('idx');
					if (idx > id) {
						id = idx;
					}
				}
				id++;
				return id;
			},

		});
		return OptionsCollection;

	});
require(['source/APP',
	'templates/templates',
	'source/Question',
	'source/views/localResult/main',
	'source/collections/localResult',
	'source/models/localResult',

	'source/views/globalResult/main',
	'source/collections/globalResult',
	'source/models/globalResult',
	'source/collections/options',
	'source/models/options',

], function(APP, templates, Question, LocalResultView, LocalResultCollection, LocalResult, GlobalResultView, GlobalResultCollection, GlobalResult, OptionsCollection, Options) {

	var adress = "http://andanka.pl/result/index.php";
	var This;
	var AppView = Backbone.View.extend({
		el: $(".main"),
		events: {
			"click .genStat": "generateStat",
			"click .StartGameID": "startGame",
			"click .RepeatID": "startGame",
			"click .MenuID": "gotoMenu",
			"click .confirmName": "confirmName",
			"click .closeAlerDialog": function() {
				$('#alertModal').modal('hide');
			},

			"click .leftID": function() {

				this.answerClick(2);
			},
			"click .rightID": function() {
				this.answerClick(3);
			},
			"click .topID": function() {
				this.answerClick(0);
			},
			"click .bottomID": function() {
				this.answerClick(1);
			},

		},
		timer: 0,
		gameInProgress: false,
		lastTime: 0,
		generators: [],
		points: 0,
		stage: 0,

		initialize: function() {

			adress = "http://andanka.pl/result/index.php";
			//adress = "http://localhost/result/index.php";

			//localStorage.clear();

			console.log("AppView");
			this.$el.html(templates['main/main.html']);

			this.localResultView = new LocalResultView();
			$('.localResult').append(this.localResultView.$el);

			this.globalResultView = new GlobalResultView();
			$('.globalResult').append(this.globalResultView.$el);

			$(window).resize(this.onResize);
			this.onResize();
			this.CreateGenerators();
			this.lastTime = this.getTick();
			setInterval(this.update, 50);
			this.gotoMenu();

		},
		CreateGenerators: function() {

			var c;
			var obj = {};

			c = 2;
			obj = {};
			obj.generator = new Question.simple(1);
			obj.startCount = 1;
			this.generators.push(obj);

			obj = {};
			obj.generator = new Question.simple(2);
			obj.startCount = 2;
			this.generators.push(obj);
			obj = {};
			obj.generator = new Question.simple(3);
			obj.startCount = 3;
			this.generators.push(obj);

			///
			obj = {};
			obj.generator = new Question.hard(1);
			obj.startCount = 1;
			this.generators.push(obj);

			obj = {};
			obj.generator = new Question.hard(2);
			obj.startCount = 2;
			this.generators.push(obj);

			obj = {};
			obj.generator = new Question.hard(3);
			obj.startCount = 3;
			this.generators.push(obj);
			///

			obj = {};
			obj.generator = new Question.veryHard(1);
			obj.startCount = 1;
			this.generators.push(obj);

			obj = {};
			obj.generator = new Question.veryHard(2);
			obj.startCount = 2;
			this.generators.push(obj);

			obj = {};
			obj.generator = new Question.veryHard(3);
			obj.startCount = c;
			this.generators.push(obj);

		},
		getTick: function() {
			var d = new Date();
			var n = d.getTime();
			return n;
		},
		gotoMenu: function() {
			this.showFrame('menu');

		},
		onResize: function() {
			var w = $(window).width();
			var h = $(window).height();
			console.log("resize " + w + " " + h);

			$('.gameFrame').height(h - 12);
			//$('.mainFrame').height(h - 26);

			//$('.gameFrame').css('min-height', h - 26 + 'px');
			$('.mainFrame').css('min-height', h - 12 + 'px');

			var bodyfontSize = Math.floor(w * 0.03);
			$('body').css("font-Size", bodyfontSize + "px");

			var ButtonfontSize = Math.floor(w * 0.04);
			$('.menuButton').css("font-Size", ButtonfontSize + "px");

			var answerButtonfontSize = Math.floor(w * 0.060);
			$('.menuButton2').css("font-Size", answerButtonfontSize + "px");

			var Button3fontSize = Math.floor(w * 0.04);
			$('.menuButton3').css("font-Size", Button3fontSize + "px");

			var buttonWidth = Math.floor(w * 0.2);
			console.log(buttonWidth);
			$('.menuButton2').css('min-width', buttonWidth + 'px');
			$('.menuButton3').css('min-width', buttonWidth + 'px');

			$('.textLable').css('min-width', buttonWidth + 'px');

		},

		showFrame: function(frame) {
			$(".frame").hide();

			if (frame == "menu") {
				$(".mainFrame").show();
				console.log("menu");

			}
			if (frame == "game") {
				$(".gameFrame").show();
				console.log("game");
			}
		},

		startGame: function() {

			/*	
		$('#alertModal').modal({
				keyboard: false,
				backdrop: 'static'
			});
*/

			this.showFrame('game');
			$(".normalGameCenter").show();
			$(".finishGameCenter").hide();
			$(".answerButton").show();
			$(".answerButton").removeClass('correctAnswer');
			$(".answerButton").removeClass('wrongAnswer');

			this.gameInProgress = true;

			for (var i = 0; i < this.generators.length; i++) {
				this.generators[i].count = this.generators[i].startCount;
			}
			this.points = 0;
			this.stage = 0;
			$(".pointsID").html(this.points);
			$(".stageID").html(this.stage);
			this.startQuestion();

			//this.addGlobalResult(123, 11);
		},

		startQuestion: function() {
			this.timer = 5000;
			this.stage++;
			$(".stageID").html(this.stage);

			this.NewQuestion();

		},
		NewQuestion: function() {
			for (var i = 0; i < this.generators.length; i++) {
				if (this.generators[i].count > 0 || i == (this.generators.length - 1)) {
					this.generators[i].count--;
					this.currentGenerator = this.generators[i].generator;
					break;
				}
			}

			this.currentGenerator.Generate();
			$(".topID").html(this.currentGenerator.m_sTop);
			$(".bottomID").html(this.currentGenerator.m_sBottom);
			$(".leftID").html(this.currentGenerator.m_sLeft);
			$(".rightID").html(this.currentGenerator.m_sRight);
			$(".QuastionID").html(this.currentGenerator.m_sQuestion);

		},

		update: function() {
			var time = This.getTick();
			var delta = time - this.lastTime;
			this.lastTime = time;

			if (This.gameInProgress === true) {
				This.timer -= delta;
				if (This.timer <= 0) {
					This.timer = 0;
					This.finishGame(1);
				}

				var s = Math.floor(This.timer / 1000);
				var m = This.timer - (s * 1000);
				m = Math.floor(m / 10)
				if (m < 10) {
					m = "0" + m;
				}
				$('.timeID').html('0' + s + ':' + m);

			}
		},

		finishGame: function(type) {
			this.gameInProgress = false;
			//$(".answerButton").hide();
			$(".normalGameCenter").hide();
			$(".finishGameCenter").show();
			var text;
			if (type == 1) {
				//zla odpowiedz
				text = "Time's Up";
				this.lastAnswer = -1;
			}

			//czas
			if (type == 0) {
				text = "Wrong answer";
			}

			if (this.currentGenerator.m_eCorrectAnswer === 0) {
				$(".topID").addClass('correctAnswer');
			}
			if (this.currentGenerator.m_eCorrectAnswer === 1) {
				$(".bottomID").addClass('correctAnswer');
			}
			if (this.currentGenerator.m_eCorrectAnswer === 2) {
				$(".leftID").addClass('correctAnswer');
			}
			if (this.currentGenerator.m_eCorrectAnswer === 3) {
				$(".rightID").addClass('correctAnswer');
			}

			if (this.lastAnswer === 0) {
				$(".topID").addClass('wrongAnswer');
			}
			if (this.lastAnswer === 1) {
				$(".bottomID").addClass('wrongAnswer');
			}
			if (this.lastAnswer === 2) {
				$(".leftID").addClass('wrongAnswer');
			}
			if (this.lastAnswer === 3) {
				$(".rightID").addClass('wrongAnswer');
			}

			var pos = this.addLocalResult(this.points, this.stage);
			if (pos != -1) {
				text += "<br>#" + pos + " - New record !!! "
			}
			var addGlobal = this.checkGlobalResultInLocalData(this.points, this.stage);
			if (addGlobal == true) {
				this.addGlobalResult(this.points, this.stage);
			}

			$('.failTypeID').html(text);

		},
		answerClick: function(id) {
			if (this.gameInProgress === false)
				return;
			console.log(id);
			this.lastAnswer = id;
			if (this.currentGenerator.m_eCorrectAnswer == id) {

				this.points += 100;
				this.points += Math.floor(10 * (this.timer) / 1000.0);
				$(".pointsID").html(this.points);

				this.startQuestion();

			} else {
				this.finishGame(0);
			}

		},

		newLocalResult: function(p, s) {
			var newID = APP.localResultCollection.getNextID();

			var model = new LocalResult({
				'points': p,
				'stage': s
			});
			model.set('idx', newID);
			APP.localResultCollection.add(model);
			model.save();

		},
		newGlobalResult: function(n, p, s) {
			var newID = APP.globalResultCollection.getNextID();

			var model = new GlobalResult({
				'points': p,
				'stage': s,
				'name': n
			});
			model.set('idx', newID);
			APP.globalResultCollection.add(model);
			model.save();

		},

		newOption: function() {
			var newID = APP.optionsCollection.getNextID();

			var model = new Options();
			model.set('idx', newID);
			APP.optionsCollection.add(model);
			model.save();

		},
		addGlobalResult: function(result, stage) {

			$('.pointsModal').html("Points: " + result + "   Stage: " + stage);

			APP.addToGloba = {
				points: result,
				stage: stage

			};
			var options = APP.optionsCollection.at(0);
			$(".playerName").val(options.get("name"));
			$('#nameModal').modal({
				keyboard: false,
				backdrop: 'static'
			});

		},

		confirmName: function() {

			var name = $(".playerName").val();
			name = name.replace(/(<([^>]+)>)/ig, "");

			var options = APP.optionsCollection.at(0);
			options.set("name", name);
			options.save();

			if (name == "") {
				name = "noname";
			}

			var jqxhr = $.ajax({
					type: "POST",
					url: adress,
					data: {
						type: 2,
						points: APP.addToGloba.points,
						stage: APP.addToGloba.stage,
						name: name
					}
				})
				.done(function(data) {
					//alert("success");
					console.log(data);
					APP.view.loadGlobalResult();

				})
				.fail(function() {
					$('#alertModal').modal({
						keyboard: false,
						backdrop: 'static'
					});

				})
				.always(function(data) {

					//alert("complete");

				});

			console.log("name " + name);
			$('#nameModal').modal('hide');

		},

		addLocalResult: function(result, stage) {
			var maxOnList = 20;
			var model;
			var add = false;
			if (result == 0) {
				return -1;
			}

			//jak jest miejsce to dodaj
			if (APP.localResultCollection.length < maxOnList) {

				var model = this.newLocalResult(result, stage);
				add = true;

			} else {

				var min = 900000000;
				var stageMin = 9000000;
				var modelMin;

				for (var i = 0; i < APP.localResultCollection.length; i++) {

					var p = APP.localResultCollection.at(i).get('points');
					var s = APP.localResultCollection.at(i).get('stage');
					if (p < min) {
						min = p;
						stageMin = s;
						modelMin = APP.localResultCollection.at(i);
					} else
					if (p === min) {
						if (s > stageMin) {
							stageMin = s;
							min = p;
							modelMin = APP.localResultCollection.at(i);
						}
					}

				}

				if (result > min || (result == min && stage < stageMin)) {
					modelMin.destroy();
					APP.localResultCollection.remove(modelMin);

					model = this.newLocalResult(result, stage);
					add = true;
				}

			}

			if (add == false) {
				console.log("no add ");

				return -1;
			} else {
				for (var i = 0; i < APP.localResultCollection.length; i++) {

					var p = APP.localResultCollection.at(i).get('points');
					var s = APP.localResultCollection.at(i).get('stage');
					if (p == result && s == stage) {
						console.log("add " + (i + 1));
						return (i + 1);
					}

				}

			}

		},

		checkGlobalResultInLocalData: function(result, stage) {
			var maxOnList = 20;
			var model;
			var add = false;
			if (result == 0) {
				return -1;
			}

			var min = 900000000;
			var stageMin = 9000000;
			var modelMin;

			for (var i = 0; i < APP.globalResultCollection.length; i++) {

				var p = APP.globalResultCollection.at(i).get('points');
				var s = APP.globalResultCollection.at(i).get('stage');
				if (p < min) {
					min = p;
					stageMin = s;
					modelMin = APP.globalResultCollection.at(i);
				} else
				if (p === min) {
					if (s > stageMin) {
						stageMin = s;
						min = p;
						modelMin = APP.globalResultCollection.at(i);
					}
				}

			}

			if (result > min || (result == min && stage < stageMin)) {
				add = true;
			}

			return add;

		},

		loadGlobalResult: function() {
			console.log("load global");

			var jqxhr = $.ajax({
					type: "POST",
					url: adress,
					data: {
						type: 3

					}
				})
				.done(function(data) {
					//alert("success");
					console.log(data);
					var obj = eval("(" + data + ')');
					console.log(obj);
					if (obj.ok === 1) {
						var options = APP.optionsCollection.at(0);

						var data = APP.getDataAsText(new Date());

						options.set("updateData", '  ' + data);
						options.save();
						console.log("jest ok");
						_.invoke(APP.globalResultCollection.toArray(), 'destroy');
						for (var i = 0; i < obj.result.length; i++) {

							var e = obj.result[i];
							var p = parseInt(e.points);
							var s = parseInt(e.stage);
							APP.view.newGlobalResult(e.name, p, s);
						}

						//APP.view.globalResultView.render();
					}

				})
				.fail(function() {

					var data = APP.optionsCollection.at(0).get("updateData");
					$(".updateData").html(data);

				})
				.always(function(data) {

					//alert("complete");

				});

		},

		render: function() {

		},

	});

	var AppRouter = Backbone.Router.extend({

		routes: {
			'': "main"
		},

		main: function() {
			console.log("routmain");
		},

	});

	Backbone.$ = $;
	console.log("test start");
	//APP.init();

	APP.localResultCollection = new LocalResultCollection();
	APP.localResultCollection.fetch();
	console.log('localResultCollection num ' + APP.localResultCollection.length);

	APP.globalResultCollection = new GlobalResultCollection();
	APP.globalResultCollection.fetch();
	console.log('globalResultCollection num ' + APP.globalResultCollection.length);

	APP.optionsCollection = new OptionsCollection();
	APP.optionsCollection.fetch();
	console.log('OptionsCollection num ' + APP.optionsCollection.length);

	if (APP.optionsCollection.length == 0) {
		console.log("add new"); {
			var newID = APP.optionsCollection.getNextID();

			var model = new Options();
			model.set('idx', newID);
			APP.optionsCollection.add(model);
			model.save();
		}
		console.log('po dodaniu OptionsCollection num ' + APP.optionsCollection.length);
	}

	APP.view = new AppView;
	This = APP.view;
	APP.router = new AppRouter();
	Backbone.history.start();

	APP.view.loadGlobalResult();

	//_.invoke(APP.localResultCollection.toArray(), 'destroy');

	//test
	/*	for (var i = 0; i < 100; i++) {
		var r = Math.floor(Math.random() * 100000) % 2000;
		var s = Math.floor(Math.random() * 100000) % 30;

		APP.view.addLocalResult(r, s);

	}
	APP.view.addLocalResult(503, 11);
	APP.view.addLocalResult(604, 11);
	APP.view.addLocalResult(201, 11);
	APP.view.addLocalResult(103, 11);
	APP.view.addLocalResult(300, 8);*/

});
define("main", function(){});
